==> dmail-1.14.tgz: dmail/dmail.h <==

/*
 * DMAIL.H
 *
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/file.h>
#include <sys/ioctl.h>
#include <sys/time.h>
#include <sys/wait.h>
#include <sys/mman.h>
#include <pwd.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include <setjmp.h>
#include <ctype.h>
#include <errno.h>

#include "execom.h"

#define Prototype 	extern

#define VERSION      "Dmail Version 1.14, 11-Aug-1997 (first release 1986)"
#define MAXTYPE      16     /* Max number of different fields remembered     */
#define EXSTART      3      /* Beginning of dynamic fields, rest are wired   */
#define MAXLIST      16     /* Maximum # list elements in SETLIST            */
#define LONGSTACK    64     /* Maximum # levels for the longjump stack       */
#define MAILMODE     0600   /* Standard mail mode for temp. files            */
#define MAXFIELDSIZE 4096   /* Maximum handlable field size (& scratch bufs) */

#define LEVEL_SET    0      /* which variable set to use                     */
#define LEVEL_ALIAS  1
#define LEVEL_MALIAS 2

#define R_INCLUDE   1       /* Include message      For DO_REPLY()  */
#define R_FORWARD   2       /* Forward message      */
#define R_REPLY     3       /* Reply to message     */
#define R_MAIL      4       /* Mail from scratch    */
#define R_FWDINCL   5       /* Forward message with commentary */

#define M_RESET     0
#define M_CONT      1

#define isfrom(str)	((str)[0] == 'F' && strncmp((str) + 1, "rom ", 4) == 0)

#define PAGER(Puf)      _pager(Puf, 1, -1)      /* Auto newline */
#define FPAGER(Puf)     _pager(Puf, 0, -1)      /* output as is */
#define WPAGER(Puf,Len) _pager(Puf, 0, Len)	/* output specific */
#define push_base()     (setjmp (env[1 + Longstack]) ? 1 : (++Longstack, 0))
#define pop_base()      --Longstack
#define push_break()    ++Breakstack
#define pop_break()     --Breakstack

#define ST_DELETED  0x0001  /* Status flag.. item has been deleted  */
#define ST_READ     0x0002  /* item has been read or marked         */
#define ST_STORED   0x0010  /* item has been written                */
#define ST_TAG      0x0020  /* item has been taged                  */
#define ST_SCR      0x0080  /* scratch flag to single out messages  */

typedef unsigned char ubyte;

struct ENTRY {
    long fpos;
    long hlen;
    long tlen;
    int  no;
    int  status;
    const char *from;
    const char *fields[MAXTYPE];
};

struct FIND {
    char *search;
    int  len;
    int  notnew;
    int  age;
};

#ifdef sgi
#define vfork fork
#endif

#include "protos.h"

==> dmail-1.18.tgz: dmail/dmail.h <==

/*
 * DMAIL.H
 *
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/file.h>
#include <sys/ioctl.h>
#include <sys/time.h>
#include <sys/wait.h>
#include <sys/mman.h>
#include <pwd.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include <setjmp.h>
#include <ctype.h>
#include <errno.h>

#include "execom.h"

#define Prototype 	extern

#define VERSION      "Dmail Version 1.18, 2-Dec-1998 (first release 1986)"
#define MAXTYPE      16     /* Max number of different fields remembered     */
#define EXSTART      3      /* Beginning of dynamic fields, rest are wired   */
#define MAXLIST      16     /* Maximum # list elements in SETLIST            */
#define LONGSTACK    64     /* Maximum # levels for the longjump stack       */
#define MAILMODE     0600   /* Standard mail mode for temp. files            */
#define MAXFIELDSIZE 4096   /* Maximum handlable field size (& scratch bufs) */

#define LEVEL_SET    0      /* which variable set to use                     */
#define LEVEL_ALIAS  1
#define LEVEL_MALIAS 2

#define R_INCLUDE   1       /* Include message      For DO_REPLY()  */
#define R_FORWARD   2       /* Forward message      */
#define R_REPLY     3       /* Reply to message     */
#define R_MAIL      4       /* Mail from scratch    */
#define R_FWDINCL   5       /* Forward message with commentary */

#define M_RESET     0
#define M_CONT      1

#define isfrom(str)	((str)[0] == 'F' && strncmp((str) + 1, "rom ", 4) == 0)

#define PAGER(Puf)      _pager(Puf, 1, -1)      /* Auto newline */
#define FPAGER(Puf)     _pager(Puf, 0, -1)      /* output as is */
#define WPAGER(Puf,Len) _pager(Puf, 0, Len)	/* output specific */
#define push_base()     (setjmp (env[1 + Longstack]) ? 1 : (++Longstack, 0))
#define pop_base()      --Longstack
#define push_break()    ++Breakstack
#define pop_break()     --Breakstack

#define STB_DELETED	0
#define STB_READ	1
#define STB_STORED	4
#define STB_TAG		5
#define STB_SCR		7

#define ST_DELETED  0x0001  /* Status flag.. item has been deleted  */
#define ST_READ     0x0002  /* item has been read or marked         */
#define ST_STORED   0x0010  /* item has been written                */
#define ST_TAG      0x0020  /* item has been taged                  */
#define ST_SCR      0x0080  /* scratch flag to single out messages  */

typedef unsigned char ubyte;

struct ENTRY {
    long fpos;
    long hlen;
    long tlen;
    int  no;
    int  status;
    const char *from;
    const char *fields[MAXTYPE];
};

struct FIND {
    char *search;
    int  len;
    int  notnew;
    int  age;
};

#ifdef sgi
#define vfork fork
#endif

#include "protos.h"
